@@ -70,7 +70,7 @@ class Manager(object):
         return self._path(id)
 
     def _create(self, url, body):
-        resp, body = self.api.json_request('POST', url, body=body)
+        resp, body = self.api.json_request('POST', url, data=body)
         if body:
             return self.resource_class(self, body)
 
@@ -100,7 +100,7 @@ class Manager(object):
         return [obj_class(self, res, loaded=True) for res in data if res]
 
     def _update(self, url, body, response_key=None):
-        resp, body = self.api.json_request('PUT', url, body=body)
+        resp, body = self.api.json_request('PUT', url, data=body)
         # PUT requests may not return a body
         if body:
             return self.resource_class(self, body)
